# Stargate - Models

Models are the smallest part of the Stargate architecture; their responsibility is to make predictions, so end-users should be able to create them by only worrying about the base logic.

All the serving abstraction and headaches should be handled by this package.
